# color_text

This is a library for printing colored texts.

这是一个用来打印彩色文字的库。

## Note  注意

> Best used in Python 3.8

> 最好在 Python 3.8 上使用

## Install  安装

```bash
pip3 install color_text
```

## Example  例子

```python
from color_text import *

printLightRed("This is a light red text.")
printYellow("This is a yellow text.")
printRed("This is a red text.")
printGreen("This is a green text.")
printBlack("This is a black text.")
printBlue("This is a blue text.")
printPurple("This is a purple text.")
printWhite("This is a white text.")
printGrey("This is a grey text.")
printGray("This is a grey text too.")
printLightBlue("This is a light blue text.")
printVeryLightGreen("This is a very light green text.")
printLightPurple("This is a light purple text.")
printLightYellow("This is a light yellow text.")
printGlossWhite("This is a gloss white text.")
printLightGreen("This is a light green text.")
printLightGreen("This is a light green text too.", 2)
Print("This is a text.")

# You can see the result of this example in the exaple() function of this library.
# 你可以在这个库的 exaple() 函数中看到这个例子的结果。（如果计算机默认语言是中文的就会看到中文结果，函数的顺序是一样的）
```

## What's new in this version  这个版本中的新功能

- Added version information.

- 增加了版本信息
